@@ -1,6 +1,7 @@
 /*  xfce4-cpu-freq-plugin - panel plugin for cpu informations
  *
  *  Copyright (c) 2006 Thomas Schreck <shrek@xfce.org>
+ *  Copyright (c) 2013 Harald Judt <h.judt@gmx.at>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef XFCE4_CPUFREQ_LINUX_H
@@ -25,6 +26,9 @@ G_BEGIN_DECLS
 gboolean
 cpufreq_update_cpus (gpointer data);
 
+gboolean
+cpufreq_intel_pstate_params (void);
+
 gboolean
 cpufreq_linux_init (void);
 
